@@ -7,10 +7,9 @@
  */
 
 #include "desktopportal.h"
+#include "desktopportal_debug.h"
 
-#include <QLoggingCategory>
-
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDesktopPortal, "xdp-kde-desktop-portal")
+#include "dynamiclauncher.h"
 
 DesktopPortal::DesktopPortal(QObject *parent)
     : QObject(parent)
@@ -23,6 +22,7 @@ DesktopPortal::DesktopPortal(QObject *parent)
     , m_notification(new NotificationPortal(this))
     , m_print(new PrintPortal(this))
     , m_settings(new SettingsPortal(this))
+    , m_dynamicLauncher(new DynamicLauncherPortal(this))
 {
     const QByteArray xdgCurrentDesktop = qgetenv("XDG_CURRENT_DESKTOP");
     if (xdgCurrentDesktop.compare("KDE", Qt::CaseInsensitive) == 0) {
