@@ -8,12 +8,36 @@
 #include <KLocalizedString>
 #include <QIcon>
 
-OutputsModel::OutputsModel(QObject *parent)
+OutputsModel::OutputsModel(Options o, QObject *parent)
     : QAbstractListModel(parent)
 {
-    m_outputs = WaylandIntegration::screens().values();
+    const auto outputs = WaylandIntegration::screens().values();
+
+    // Only show the full workspace if there's several outputs
+    if (outputs.count() > 1 && (o & WorkspaceIncluded)) {
+        m_outputs << Output{WaylandIntegration::WaylandOutput::Workspace, 0, i18n("Full Workspace"), "Workspace"};
+    }
+    if (o & VirtualIncluded) {
+        static quint64 i = 0;
+        m_outputs << Output{WaylandIntegration::WaylandOutput::Virtual, 0, i18n("New Virtual Output"), QStringLiteral("Virtual%1").arg(i++)};
+    }
+    for (auto output : outputs) {
+        QString display;
+        switch (output.outputType()) {
+        case WaylandIntegration::WaylandOutput::Laptop:
+            display = i18n("Laptop screen\nModel: %1", output.model());
+            break;
+        default:
+            display = i18n("Manufacturer: %1\nModel: %2", output.manufacturer(), output.model());
+            break;
+        }
+        const QPoint pos = output.globalPosition();
+        m_outputs << Output{output.outputType(), output.waylandOutputName(), display, QStringLiteral("%1x%2").arg(pos.x()).arg(pos.y())};
+    }
 }
 
+OutputsModel::~OutputsModel() = default;
+
 int OutputsModel::rowCount(const QModelIndex &parent) const
 {
     return parent.isValid() ? 0 : m_outputs.count();
@@ -40,23 +64,11 @@ QVariant OutputsModel::data(const QModelIndex &index, int role) const
     case Qt::UserRole:
         return output.waylandOutputName();
     case Qt::DecorationRole:
-        switch (output.outputType()) {
-        case WaylandIntegration::WaylandOutput::Laptop:
-            return QIcon::fromTheme(QStringLiteral("computer-laptop"));
-        case WaylandIntegration::WaylandOutput::Monitor:
-            return QIcon::fromTheme(QStringLiteral("video-display"));
-        case WaylandIntegration::WaylandOutput::Television:
-            return QIcon::fromTheme(QStringLiteral("video-television"));
-        }
+        return QIcon::fromTheme(output.iconName());
     case Qt::DisplayRole:
-        switch (output.outputType()) {
-        case WaylandIntegration::WaylandOutput::Laptop:
-            return i18n("Laptop screen\nModel: %1", output.model());
-        default:
-            return i18n("Manufacturer: %1\nModel: %2", output.manufacturer(), output.model());
-        }
+        return output.display();
     case Qt::CheckStateRole:
-        return m_selected.contains(output.waylandOutputName()) ? Qt::Checked : Qt::Unchecked;
+        return m_selectedRows.contains(index.row()) ? Qt::Checked : Qt::Unchecked;
     }
     return {};
 }
@@ -71,38 +83,45 @@ bool OutputsModel::setData(const QModelIndex &index, const QVariant &value, int
         return true;
     }
 
-    const auto &output = m_outputs[index.row()];
     if (value == Qt::Checked) {
-        m_selected.insert(output.waylandOutputName());
+        m_selectedRows.insert(index.row());
     } else {
-        m_selected.remove(output.waylandOutputName());
+        m_selectedRows.remove(index.row());
     }
     Q_EMIT dataChanged(index, index, {role});
-    if (m_selected.count() <= 1) {
+    if (m_selectedRows.count() <= 1) {
         Q_EMIT hasSelectionChanged();
     }
     return true;
 }
 
-QList<quint32> OutputsModel::selectedScreens() const
+const Output &OutputsModel::outputAt(int row) const
 {
-    return m_selected.values();
+    return m_outputs[row];
 }
 
 void OutputsModel::clearSelection()
 {
-    if (m_selected.isEmpty())
+    if (m_selectedRows.isEmpty())
         return;
 
-    auto selected = m_selected;
-    m_selected.clear();
-    int i = 0;
-    for (const auto &output : qAsConst(m_outputs)) {
-        if (selected.contains(output.waylandOutputName())) {
+    auto selected = m_selectedRows;
+    m_selectedRows.clear();
+    for (int i = 0, c = rowCount({}); i < c; ++i) {
+        if (selected.contains(i)) {
             const auto idx = index(i, 0);
             Q_EMIT dataChanged(idx, idx, {Qt::CheckStateRole});
         }
-        ++i;
     }
     Q_EMIT hasSelectionChanged();
 }
+
+QList<Output> OutputsModel::selectedOutputs() const
+{
+    QList<Output> ret;
+    ret.reserve(m_selectedRows.count());
+    for (auto x : qAsConst(m_selectedRows)) {
+        ret << m_outputs[x];
+    }
+    return ret;
+}
