@@ -10,6 +10,7 @@
 #include "screencast.h"
 #include "notificationinhibition.h"
 #include "request.h"
+#include "screencast_debug.h"
 #include "screenchooserdialog.h"
 #include "session.h"
 #include "utils.h"
@@ -24,9 +25,6 @@
 #include <QDBusMetaType>
 #include <QDataStream>
 #include <QIODevice>
-#include <QLoggingCategory>
-
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeScreenCast, "xdp-kde-screencast")
 
 struct RestoreData {
     static uint currentRestoreDataVersion()
@@ -233,12 +231,7 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
                         const QModelIndex index = model.index(i, 0);
 
                         if (model.data(index, KWayland::Client::PlasmaWindowModel::Uuid) == windowUuid) {
-                            // For some reason itemData() doesn't return a map with all the data
-                            // we need and for example UUID is missing, which is the most important
-                            // information we need for stream restoration.
-                            QMap<int, QVariant> data = model.itemData(index);
-                            data.insert(KWayland::Client::PlasmaWindowModel::Uuid, windowUuid);
-                            selectedWindows << data;
+                            selectedWindows << model.itemData(index);
                         }
                     }
                 }
@@ -291,7 +284,7 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
             streams << stream;
         }
         for (const auto &win : qAsConst(selectedWindows)) {
-            WaylandIntegration::Stream stream = WaylandIntegration::startStreamingWindow(win);
+            WaylandIntegration::Stream stream = WaylandIntegration::startStreamingWindow(win, Screencasting::CursorMode(session->cursorMode()));
             if (!stream.isValid()) {
                 qCWarning(XdgDesktopPortalKdeScreenCast) << "Invalid window!" << win;
                 return 2;
