@@ -4,21 +4,22 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
  */
 
 #include "waylandintegration.h"
 #include "screencast.h"
 #include "screencasting.h"
+#include "waylandintegration_debug.h"
 #include "waylandintegration_p.h"
 
-#include <QDBusArgument>
 #include <QDBusMetaType>
 #include <QGuiApplication>
 
 #include <KNotification>
 #include <QEventLoop>
 #include <QImage>
-#include <QLoggingCategory>
+#include <QMenu>
 #include <QScreen>
 #include <QThread>
 #include <QTimer>
@@ -41,8 +42,6 @@
 #include <KStatusNotifierItem>
 #include <KWayland/Client/fakeinput.h>
 
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeWaylandIntegration, "xdp-kde-wayland-integration")
-
 Q_GLOBAL_STATIC(WaylandIntegration::WaylandIntegrationPrivate, globalWaylandIntegration)
 
 namespace WaylandIntegration
@@ -125,9 +124,9 @@ WaylandIntegration::Stream WaylandIntegration::startStreamingVirtual(const QStri
     return globalWaylandIntegration->startStreamingVirtualOutput(name, size, mode);
 }
 
-WaylandIntegration::Stream WaylandIntegration::startStreamingWindow(const QMap<int, QVariant> &win)
+WaylandIntegration::Stream WaylandIntegration::startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode)
 {
-    return globalWaylandIntegration->startStreamingWindow(win);
+    return globalWaylandIntegration->startStreamingWindow(win, mode);
 }
 
 void WaylandIntegration::stopAllStreaming()
@@ -170,6 +169,21 @@ void WaylandIntegration::requestKeyboardKeycode(int keycode, bool state)
     globalWaylandIntegration->requestKeyboardKeycode(keycode, state);
 }
 
+void WaylandIntegration::requestTouchDown(quint32 touchPoint, const QPointF &pos)
+{
+    globalWaylandIntegration->requestTouchDown(touchPoint, pos);
+}
+
+void WaylandIntegration::requestTouchMotion(quint32 touchPoint, const QPointF &pos)
+{
+    globalWaylandIntegration->requestTouchMotion(touchPoint, pos);
+}
+
+void WaylandIntegration::requestTouchUp(quint32 touchPoint)
+{
+    globalWaylandIntegration->requestTouchUp(touchPoint);
+}
+
 QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::screens()
 {
     return globalWaylandIntegration->screens();
@@ -246,12 +260,13 @@ void WaylandIntegration::WaylandIntegrationPrivate::startStreamingInput()
     m_streamInput = true;
 }
 
-WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingWindow(const QMap<int, QVariant> &win)
+WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingWindow(const QMap<int, QVariant> &win,
+                                                                                               Screencasting::CursorMode cursorMode)
 {
     auto uuid = win[KWayland::Client::PlasmaWindowModel::Uuid].toString();
     QString iconName = win[Qt::DecorationRole].value<QIcon>().name();
     iconName = iconName.isEmpty() ? QStringLiteral("applications-all") : iconName;
-    return startStreaming(m_screencasting->createWindowStream(uuid, Screencasting::Hidden),
+    return startStreaming(m_screencasting->createWindowStream(uuid, cursorMode),
                           iconName,
                           i18n("Recording window \"%1\"...", win[Qt::DisplayRole].toString()),
                           {{QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Window)}});
@@ -323,7 +338,6 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
         ret.nodeId = nodeid;
         ret.map = streamOptions;
         m_streams.append(ret);
-        startStreamingInput();
 
         connect(stream, &ScreencastingStream::closed, this, [this, nodeid] {
             stopStreaming(nodeid);
@@ -336,12 +350,19 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
         item->setTitle(description);
         item->setIconByName(iconName);
         item->setOverlayIconByName(QStringLiteral("media-record"));
-        item->setToolTip(item->iconName(), item->title(), i18n("Press to cancel"));
         item->setStatus(KStatusNotifierItem::Active);
-        connect(item, &KStatusNotifierItem::activateRequested, stream, [=] {
+        connect(item, &KStatusNotifierItem::activateRequested, stream, [item] {
+            item->contextMenu()->show();
+        });
+        auto menu = new QMenu;
+        auto stopAction =
+            new QAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18nc("@action:inmenu stops screen/window recording", "Stop Recording"));
+        connect(stopAction, &QAction::triggered, this, [this, nodeid, stream] {
             stopStreaming(nodeid);
             stream->deleteLater();
         });
+        menu->addAction(stopAction);
+        item->setContextMenu(menu);
 
         loop.quit();
     });
@@ -429,6 +450,27 @@ void WaylandIntegration::WaylandIntegrationPrivate::requestKeyboardKeycode(int k
     }
 }
 
+void WaylandIntegration::WaylandIntegrationPrivate::requestTouchDown(quint32 touchPoint, const QPointF &pos)
+{
+    if (m_streamInput && m_fakeInput) {
+        m_fakeInput->requestTouchDown(touchPoint, pos);
+    }
+}
+
+void WaylandIntegration::WaylandIntegrationPrivate::requestTouchMotion(quint32 touchPoint, const QPointF &pos)
+{
+    if (m_streamInput && m_fakeInput) {
+        m_fakeInput->requestTouchMotion(touchPoint, pos);
+    }
+}
+
+void WaylandIntegration::WaylandIntegrationPrivate::requestTouchUp(quint32 touchPoint)
+{
+    if (m_streamInput && m_fakeInput) {
+        m_fakeInput->requestTouchUp(touchPoint);
+    }
+}
+
 QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::WaylandIntegrationPrivate::screens()
 {
     return m_outputMap;
