@@ -133,7 +133,7 @@ void startStreamingInput();
 Stream startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode);
 Stream startStreamingWorkspace(Screencasting::CursorMode mode);
 Stream startStreamingVirtual(const QString &name, const QSize &size, Screencasting::CursorMode mode);
-Stream startStreamingWindow(const QMap<int, QVariant> &win);
+Stream startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode);
 void stopAllStreaming();
 void stopStreaming(uint node);
 
@@ -145,6 +145,10 @@ void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
 
 void requestKeyboardKeycode(int keycode, bool state);
 
+void requestTouchDown(quint32 touchPoint, const QPointF &pos);
+void requestTouchMotion(quint32 touchPoint, const QPointF &pos);
+void requestTouchUp(quint32 touchPoint);
+
 QMap<quint32, WaylandOutput> screens();
 
 void setParentWindow(QWindow *window, const QString &parentWindow);
